@@ -22,8 +22,8 @@
 #include <pwd.h>
 #include <signal.h>
 
-#include <gpilotd/gnome-pilot-conduit.h>
-#include <gpilotd/gnome-pilot-conduit-standard.h>
+#include <gnome-pilot-conduit.h>
+#include <gnome-pilot-conduit-standard.h>
 #include "email_conduit.h"
 
 #define CONDUIT_VERSION "0.10"
@@ -809,10 +809,10 @@ static GtkWidget
     /* send_action option menu */
     label = gtk_label_new(_("Send Action:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    widget = gtk_combo_box_new_text ();
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widget),  (_("Delete from PDA")));
+    widget = gtk_combo_box_text_new ();
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget),  (_("Delete from PDA")));
     g_object_set_data(G_OBJECT(widget), EC_SEND_ACTION[0], GINT_TO_POINTER(0));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("File on PDA"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget), _("File on PDA"));
     g_object_set_data(G_OBJECT(widget), EC_SEND_ACTION[1], GINT_TO_POINTER(1));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table), widget, 1, 2, 0, 1);
@@ -840,12 +840,12 @@ static GtkWidget
     /* receive_action option menu */
     label = gtk_label_new (_("Receive Action:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    widget = gtk_combo_box_new_text ();
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Copy from Inbox"));
+    widget = gtk_combo_box_text_new ();
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget), _("Copy from Inbox"));
     g_object_set_data(G_OBJECT(widget), EC_RECV_ACTION[0], GINT_TO_POINTER(0));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Delete from Inbox"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget), _("Delete from Inbox"));
     g_object_set_data(G_OBJECT(widget), EC_RECV_ACTION[1], GINT_TO_POINTER(1));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Mirror Inbox"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget), _("Mirror Inbox"));
     g_object_set_data(G_OBJECT(widget), EC_RECV_ACTION[2], GINT_TO_POINTER(2));
     gtk_table_attach_defaults (GTK_TABLE(table), label, 0, 1, 3, 4);
     gtk_table_attach_defaults(GTK_TABLE(table), widget, 1, 2, 3, 4);
@@ -997,7 +997,7 @@ revert_settings  (GnomePilotConduit *conduit, gpointer data)
 
 GnomePilotConduit *conduit_get_gpilot_conduit( guint32 pilotId ) 
 {
-  GtkObject *retval;
+  GObject *retval;
   ConduitCfg *cfg1, *cfg2;
 
   retval = gnome_pilot_conduit_standard_new("MailDB",0x6d61696c, NULL);
@@ -1044,7 +1044,7 @@ void conduit_destroy_gpilot_conduit( GnomePilotConduit *c )
   g_list_free(inbox_list);
   inbox_list = NULL;
 
-  gtk_object_destroy(GTK_OBJECT(c));
+  g_object_unref (G_OBJECT (c));
 }
 
 #define OLD_PREFIX ".gnome2/gnome-pilot.d"
