@@ -2,8 +2,13 @@
 
 /* expense conduit, based on read-expense */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include <pi-source.h>
 #include <pi-socket.h>
@@ -13,20 +18,26 @@
 #include <errno.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <ctype.h>
 #include <utime.h>
 #include <unistd.h>
 #include <pwd.h>
 #include <signal.h>
 #include <time.h>
 
-#include <gpilotd/gnome-pilot-conduit.h>
-#include <gpilotd/gnome-pilot-conduit-standard.h>
+#include <gnome-pilot-conduit.h>
+#include <gnome-pilot-conduit-standard.h>
 #include "expense_conduit.h"
 
 #define CONDUIT_VERSION "0.3"
 
+#define EC_PAD 8
+
 GnomePilotConduit *conduit_get_gpilot_conduit( guint32 pilotId );
 void conduit_destroy_gpilot_conduit( GnomePilotConduit *c );
+static gboolean save_config (GKeyFile    *kfile, const gchar *conf);
+static GKeyFile* get_kfile (const gchar *conf);
+static void migrate_conf (const gchar *old, const gchar *new);
 
 /* Following depend on the ordering in pi-expense.h ! */
 static gchar *ExpenseTypeName[] = { "Airfare", "Breakfast", "Bus", "BusinessMeals", "CarRental", 
@@ -55,56 +66,83 @@ static gchar *ExpenseCurrencyName[] = { "AU$", "S", "BF", "R$", "$CN", "DKK", "M
 static void 
 load_configuration(ConduitCfg **c,guint32 pilotId) 
 {
-	gchar *prefix;
+	gchar *iPilot;
+	GKeyFile *kfile;
+	GError *error = NULL;
+
 	gchar *tempbuf;
 
 	g_assert(c!=NULL);
 	*c = g_new0(ConduitCfg,1);
 	(*c)->child = -1;
 
-	prefix = g_strdup_printf(CONFIG_PREFIX,pilotId);
-  
-	gnome_config_push_prefix(prefix);
-	(*c)->dir = gnome_config_get_string( "dir");
-	(*c)->dateFormat = gnome_config_get_string( "date_format=%x");
-	(*c)->outputFormat = gnome_config_get_int("output_format=0");
-	tempbuf = gnome_config_get_string("dir mode=0700");
+ 	kfile = get_kfile("expense-conduit");
+	iPilot = g_strdup_printf ("Pilot_%u", pilotId);
+
+  	(*c)->dir = g_key_file_get_string (kfile, iPilot, "dir", &error);
+        if (error) {
+                (*c)->dir = NULL;
+                error = NULL;
+        }
+
+	(*c)->dateFormat = g_key_file_get_string (kfile, iPilot, "date_format", &error);
+        if (error) {
+                (*c)->dateFormat = g_strdup("%x");
+                error = NULL;
+        }
+
+	(*c)->outputFormat = g_key_file_get_integer (kfile, iPilot, "output_format", &error);
+        if (error) {
+                (*c)->outputFormat = 0;
+                error = NULL;
+        }
+
+        tempbuf = g_key_file_get_string (kfile, iPilot, "dir mode", &error);
+        if (error) {
+                tempbuf = g_strdup("0700");
+                error = NULL;
+        }
 	(*c)->dirMode =(mode_t)strtol(tempbuf,NULL,0);
 	g_free(tempbuf);
-	tempbuf = gnome_config_get_string("file mode=0600");
-	(*c)->fileMode =(mode_t)strtol(tempbuf,NULL,0);
+
+        tempbuf = g_key_file_get_string (kfile, iPilot, "file mode", &error);
+        if (error) {
+                tempbuf = g_strdup("0600");
+                error = NULL;
+        }
+        (*c)->fileMode =(mode_t)strtol(tempbuf,NULL,0);
 	g_free(tempbuf);
 
-	gnome_config_pop_prefix();
 
 	(*c)->pilotId = pilotId;
-	g_free(prefix);
+	g_free (iPilot);
+        g_key_file_free (kfile);
 }
 
 static void 
 save_configuration(ConduitCfg *c) 
 {
-	gchar *prefix;
+	gchar *iPilot;
+	GKeyFile *kfile;
+
         char buf[20];
 
 	g_assert(c!=NULL);
 
-	prefix = g_strdup_printf("/gnome-pilot.d/expense-conduit/Pilot_%u/",c->pilotId);
+ 	kfile = get_kfile("expense-conduit");
+	iPilot = g_strdup_printf ("Pilot_%u", c->pilotId);
 
-	gnome_config_push_prefix(prefix);
-	gnome_config_set_string("dir", c->dir);
-	gnome_config_set_string("date_format", c->dateFormat);
-	gnome_config_set_int("output_format", c->outputFormat);
+        g_key_file_set_string (kfile, iPilot, "dir", c->dir);
+        g_key_file_set_string (kfile, iPilot, "date_format", c->dateFormat);
+        g_key_file_set_integer (kfile, iPilot, "output_format", c->outputFormat);
 	g_snprintf(buf,sizeof(buf),"0%o", c->dirMode);
-	gnome_config_set_string("dir mode", buf);
+        g_key_file_set_string (kfile, iPilot, "dir mode", buf);
 	g_snprintf(buf,sizeof(buf),"0%o", c->fileMode);
-	gnome_config_set_string("file mode", buf);
+        g_key_file_set_string (kfile, iPilot, "file mode", buf);
 
-	gnome_config_pop_prefix();
+	g_free (iPilot);
 
-	gnome_config_sync();
-	gnome_config_drop_all();
-	g_free(prefix);
+	save_config (kfile, "expense-conduit");
 }
  
 static void 
@@ -180,8 +218,8 @@ static gchar *category_path(int category, GnomePilotConduit *c)
 	static gchar filename[FILENAME_MAX];
 	gchar buf[64];
 	
-	if(category==16) 
-		strcpy(buf,"Archived");
+	if(category < 0 || category >= 16)
+		strcpy(buf,"BogusCategory");
 	else
 		protect_name(buf,GET_CONDUIT_DATA(c)->ai.category.name[category]);
   
@@ -238,17 +276,25 @@ package, Copyright (c) 1997, Kenneth Albanowski
 static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
 {
         int dbHandle;
+#ifdef PILOT_LINK_0_12
+        pi_buffer_t *pi_buf;
+#else
         guchar buffer[0xffff];
+#endif
 
         struct ExpenseAppInfo *tai;
         struct ExpensePref *tp;
 
         int i;
         int ret;
-        int filehandle[17];
+        const int numhandles = 16; /* number of categories. See pi-appinfo.h  */
+        int filehandle[numhandles];
         int result = 0;
 
-        if(GET_CONDUIT_CFG(c)->dir==NULL) {
+        for (i = 0; i < numhandles; i++)
+                filehandle[i] = -1;
+
+        if(GET_CONDUIT_CFG(c)->dir==NULL || strlen(GET_CONDUIT_CFG(c)->dir)==0) {
 		g_warning(_("No dir specified. Please run expense conduit capplet first."));
 		gnome_pilot_conduit_send_error(c,
                                                _("No dir specified. Please run expense conduit capplet first."));
@@ -264,7 +310,12 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
                 return -1;
         }
     
+#ifdef PILOT_LINK_0_12
+        pi_buf = pi_buffer_new (0xffff);     
+        unpack_ExpensePref(tp, pi_buf->data, 0xffff);        
+#else
         unpack_ExpensePref(tp, buffer, 0xffff);
+#endif
 
 #ifdef EC_DEBUG
         fprintf(stderr, "Orig prefs, %d bytes:\n", ret);
@@ -280,9 +331,13 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
         fprintf(stderr, "\n");
 #endif /* EC_DEBUG */
 
+#ifdef PILOT_LINK_0_12
+        ret = dlp_ReadAppBlock(dbi->pilot_socket, dbHandle, 0, 0xffff, pi_buf);
+        unpack_ExpenseAppInfo(tai, pi_buf->data, 0xffff);
+#else
         ret = dlp_ReadAppBlock(dbi->pilot_socket, dbHandle, 0, buffer, 0xffff);
-    
         unpack_ExpenseAppInfo(tai, buffer, 0xffff);
+#endif
 
 #ifdef EC_DEBUG
         fprintf(stderr, "Orig length %d, new length %d, orig data:\n", ret, i);
@@ -305,7 +360,8 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
         }
         
         /* open one file for every category in Expense */
-        for(i = 0; i < 17; i++) {
+        for(i = 0; i < numhandles; i++) {
+                /* skip unused categories */
                 if(*tai->category.name[i] != '\0') {
                         LOG("Opening for cat %d: %s\n", i, category_path(i, c));
                         if((filehandle[i] = creat(category_path(i, c), GET_CONDUIT_CFG(c)->fileMode))== -1) {
@@ -323,7 +379,11 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
                 struct Expense t;
                 int attr, category, len;
 
+#ifdef PILOT_LINK_0_12
+                len = dlp_ReadRecordByIndex(dbi->pilot_socket, dbHandle, i, pi_buf, 0, &attr, &category);
+#else
                 len = dlp_ReadRecordByIndex(dbi->pilot_socket, dbHandle, i, buffer, 0, 0, &attr, &category);
+#endif
                 
                 /* at the end of all the records? */
                 if(len < 0)
@@ -332,7 +392,21 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
                 if((attr & dlpRecAttrDeleted) || (attr & dlpRecAttrArchived))
                         continue;
 
-                unpack_Expense(&t, buffer, len);
+#ifdef PILOT_LINK_0_12
+                unpack_Expense(&t, pi_buf->data, len);
+#else
+                unpack_Expense(&t, buffer, len);                
+#endif
+                /* PalmOS should give us a 4-bit category, and that's all that
+                 * pi-appinfo.h can cope with, but lets be cautious */
+                if (category < 0 || category >= 16) {
+                        g_warning ("Out-of-range category ID from device: %d\n", category);
+                        goto error;
+                }
+                if (filehandle[category] == -1) {
+                        g_warning ("Unexpected category ID from device: %d\n", category);
+                        goto error;
+                }
                 writeout_record(filehandle[category], &t, c);
                 free_Expense(&t);
         }
@@ -342,13 +416,19 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
         result = -1;
  exit:
         /* close all the opened filehandles */
-        for(i = 0; i < 17; i++)
+        for(i = 0; i < numhandles; i++)
                 if(filehandle[i] != -1)
                         close(filehandle[i]);
 
         /* Close the database */
         dlp_CloseDB(dbi->pilot_socket, dbHandle);
         
+#ifdef PILOT_LINK_0_12
+        if (pi_buf) {
+                pi_buffer_free (pi_buf);
+        }
+#endif
+         
         return( result );
 }
 
@@ -369,13 +449,13 @@ insert_ignore_space_cb (GtkEditable    *editable, const gchar    *text,
         curname = gtk_entry_get_text(GTK_ENTRY(editable));
         if (*curname == '\0' && len > 0) {
                 if (isspace(text[0])) {
-                        gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), "insert_text");
+                        g_signal_stop_emission_by_name(G_OBJECT(editable), "insert_text");
                         return;
                 }
         } else {
                 for (i=0; i<len; i++) {
                         if (isspace(text[i])) {
-                                gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), 
+                                g_signal_stop_emission_by_name(G_OBJECT(editable), 
                                                              "insert_text");
                                 return;
                         }
@@ -391,7 +471,7 @@ insert_numeric_cb(GtkEditable    *editable, const gchar    *text,
 
 	for (i=0; i<len; i++) {
 		if (!isdigit(text[i])) {
-			gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), "insert_text");
+			g_signal_stop_emission_by_name(G_OBJECT(editable), "insert_text");
 			return;
 		}
 	}
@@ -429,9 +509,9 @@ struct _FieldInfo
 };
 
 
-FieldInfo fields[] = { { N_("Expense Directory"), NULL, "ExpenseDir", insert_ignore_space_cb},
-                       { N_("Directory Mode"), NULL, "DirMode", insert_numeric_cb},
-                       { N_("File Mode"), NULL, "FileMode", insert_numeric_cb}, 
+static FieldInfo fields[] = { { N_("Expense Directory:"), NULL, "ExpenseDir", insert_ignore_space_cb},
+                       { N_("Directory Mode:"), NULL, "DirMode", insert_numeric_cb},
+                       { N_("File Mode:"), NULL, "FileMode", insert_numeric_cb}, 
                        { NULL, NULL, NULL, NULL}
 };
 
@@ -440,55 +520,45 @@ static GtkWidget
 {
 	GtkWidget *vbox, *table;
 	GtkWidget *entry, *label;
-        GtkWidget *menuItem, *optionMenu;
-        GtkMenu   *menu;
+        GtkWidget *optionMenu;
 
         int i, count=0, widget_offset;
 
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD);
+	vbox = gtk_vbox_new(FALSE, EC_PAD);
 
 	table = gtk_table_new(2, 5, FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 10);
-	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, GNOME_PAD);
+	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, EC_PAD);
 
         /* set the date format */
-        label = gtk_label_new(_("Date Format"));
+        label = gtk_label_new(_("Date Format:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
 
-        menu = GTK_MENU(gtk_menu_new());
+        optionMenu = gtk_combo_box_text_new();
         for (i = 0; i < DATE_OPTIONS_COUNT; i++) {
-                menuItem = gtk_menu_item_new_with_label(_(date_options[i].name));
-                gtk_widget_show(menuItem);
-                gtk_object_set_data(GTK_OBJECT(menuItem), "format",
-                                    date_options[i].format);
-                gtk_menu_append(menu, menuItem);
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(optionMenu),
+                    _(date_options[i].name));
         }
 
-        optionMenu = gtk_option_menu_new(); 
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(optionMenu),GTK_WIDGET(menu));
-
         gtk_table_attach_defaults(GTK_TABLE(table), optionMenu, 1, 2, 1, 2);
-        gtk_object_set_data(GTK_OBJECT(vbox), "DateFormat", optionMenu);
+        g_object_set_data(G_OBJECT(vbox), "DateFormat", optionMenu);
 
         /* set the writeout format */
-        label = gtk_label_new(_("Output Format"));
+        label = gtk_label_new(_("Output Format:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+
         gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 2, 3);
 
-        menu = GTK_MENU(gtk_menu_new());
+        optionMenu = gtk_combo_box_text_new(); 
         for (i = 0; i < WRITEOUT_OPTIONS_COUNT; i++) {
-                menuItem = gtk_menu_item_new_with_label(_(writeout_options[i].name));
-                gtk_widget_show(menuItem);
-                gtk_object_set_data (GTK_OBJECT (menuItem), "format", 
-                                     &writeout_options[i].format);
-                gtk_menu_append(menu, menuItem);
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (optionMenu),
+                    _(writeout_options[i].name));
         }
 
-        optionMenu = gtk_option_menu_new(); 
-        gtk_option_menu_set_menu(GTK_OPTION_MENU(optionMenu),GTK_WIDGET(menu));
-
         gtk_table_attach_defaults(GTK_TABLE(table), optionMenu, 1, 2, 2, 3);
-        gtk_object_set_data(GTK_OBJECT(vbox), "OutputFormat", optionMenu);
+        g_object_set_data(G_OBJECT(vbox), "OutputFormat", optionMenu);
 
         /* ugh, so we have an asymmetry here: above is done in paste&copy fashion 
            and below, we do it nicely with structs and stuff */  
@@ -501,17 +571,19 @@ static GtkWidget
         widget_offset = 3;
 	for(i = 0; i < count; i++) {
 		label = gtk_label_new(_(fields[i].name));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 
-                                 widget_offset+i, widget_offset+i+1, 0,0,0,0);
+                gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+                gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1,
+                	widget_offset+i, widget_offset+i+1);
 		if(fields[i].label_data!=NULL) {
-			gtk_object_set_data(GTK_OBJECT(vbox), fields[i].label_data, label);
+			g_object_set_data(G_OBJECT(vbox), fields[i].label_data, label);
 		}
-		entry = gtk_entry_new_with_max_length(128);
-		gtk_object_set_data(GTK_OBJECT(vbox), fields[i].obj_data, entry);
+		entry = gtk_entry_new();
+                gtk_entry_set_max_length(GTK_ENTRY(entry), 128);
+		g_object_set_data(G_OBJECT(vbox), fields[i].obj_data, entry);
 		gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 
                                  widget_offset+i, widget_offset+i+1, 0,0,0,0);
-		gtk_signal_connect(GTK_OBJECT(entry), "insert_text",
-				   GTK_SIGNAL_FUNC(fields[i].insert_func),
+		g_signal_connect(G_OBJECT(entry), "insert_text",
+				   G_CALLBACK(fields[i].insert_func),
 				   NULL);
 	}
 	
@@ -527,11 +599,11 @@ setOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
 
         int i;
 
-	DateFormat = gtk_object_get_data(GTK_OBJECT(pilotcfg), "DateFormat");
-	OutputFormat = gtk_object_get_data(GTK_OBJECT(pilotcfg), "OutputFormat");
-	ExpenseDir = gtk_object_get_data(GTK_OBJECT(pilotcfg), "ExpenseDir");
-	DirMode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "DirMode");
-	FileMode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "FileMode");
+	DateFormat = g_object_get_data(G_OBJECT(pilotcfg), "DateFormat");
+	OutputFormat = g_object_get_data(G_OBJECT(pilotcfg), "OutputFormat");
+	ExpenseDir = g_object_get_data(G_OBJECT(pilotcfg), "ExpenseDir");
+	DirMode = g_object_get_data(G_OBJECT(pilotcfg), "DirMode");
+	FileMode = g_object_get_data(G_OBJECT(pilotcfg), "FileMode");
 
 	g_assert(DateFormat != NULL);
 	g_assert(OutputFormat != NULL);
@@ -546,36 +618,34 @@ setOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
 	gtk_entry_set_text(GTK_ENTRY(FileMode),buf);
 
         /* find the entry in the option menu. if not found, default to the last */
-        for(i = 0; i < DATE_OPTIONS_COUNT && g_strncasecmp(state->dateFormat, date_options[i].format, 20) != 0; i++);
-        gtk_option_menu_set_history(GTK_OPTION_MENU(DateFormat), i);
+        for(i = 0; i < DATE_OPTIONS_COUNT && g_ascii_strncasecmp(state->dateFormat, date_options[i].format, 20) != 0; i++);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(DateFormat), i);
 
         for(i = 0; i < WRITEOUT_OPTIONS_COUNT && state->outputFormat != writeout_options[i].format; i++);
-        gtk_option_menu_set_history(GTK_OPTION_MENU(OutputFormat), i);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(OutputFormat), i);
 }
 
 static void
 readOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
 {
 	GtkWidget *ExpenseDir, *DirMode, *FileMode;
-        GtkWidget *option_menu, *menu, *menu_item;
+        GtkWidget *combo_box;
         
-	ExpenseDir = gtk_object_get_data(GTK_OBJECT(pilotcfg), "ExpenseDir");
-	DirMode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "DirMode");
-	FileMode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "FileMode");
+	ExpenseDir = g_object_get_data(G_OBJECT(pilotcfg), "ExpenseDir");
+	DirMode = g_object_get_data(G_OBJECT(pilotcfg), "DirMode");
+	FileMode = g_object_get_data(G_OBJECT(pilotcfg), "FileMode");
 
         state->dir = g_strdup(gtk_entry_get_text(GTK_ENTRY(ExpenseDir)));
         state->dirMode = strtol(gtk_entry_get_text(GTK_ENTRY(DirMode)), NULL, 0);
         state->fileMode = strtol(gtk_entry_get_text(GTK_ENTRY(FileMode)), NULL, 0);
 
-        option_menu = gtk_object_get_data(GTK_OBJECT(pilotcfg), "DateFormat");
-        menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(option_menu));
-        menu_item = gtk_menu_get_active (GTK_MENU (menu));
-        state->dateFormat = g_strdup((gchar*)gtk_object_get_data(GTK_OBJECT(menu_item),"format"));
+        combo_box = g_object_get_data(G_OBJECT(pilotcfg), "DateFormat");
+        state->dateFormat = g_strdup(date_options[
+                gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box))].format);
 
-        option_menu = gtk_object_get_data(GTK_OBJECT(pilotcfg), "OutputFormat");
-        menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(option_menu));
-        menu_item = gtk_menu_get_active (GTK_MENU (menu));
-        state->outputFormat = *(enum ExpenseOutputFormat*)gtk_object_get_data(GTK_OBJECT(menu_item),"format");
+        combo_box = g_object_get_data(G_OBJECT(pilotcfg), "OutputFormat");
+        state->outputFormat = writeout_options[
+            gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box))].format;
         
 }
 
@@ -588,7 +658,7 @@ create_settings_window (GnomePilotConduit *conduit, GtkWidget *parent, gpointer
 	gtk_container_add(GTK_CONTAINER(parent),cfgWindow);
 	gtk_widget_show_all(cfgWindow);
 
-	gtk_object_set_data(GTK_OBJECT(conduit),OBJ_DATA_CONFIG_WINDOW,cfgWindow);
+	g_object_set_data(G_OBJECT(conduit),OBJ_DATA_CONFIG_WINDOW,cfgWindow);
 	setOptionsCfg(GET_CONDUIT_WINDOW(conduit),GET_CONDUIT_CFG(conduit));
 
 	return 0;
@@ -621,30 +691,30 @@ revert_settings  (GnomePilotConduit *conduit, gpointer data)
 
 GnomePilotConduit *conduit_get_gpilot_conduit( guint32 pilotId ) 
 {
-        GtkObject *retval;
+        GObject *retval;
         ConduitCfg *cfg, *cfg2;
         ConduitData *cd = g_new0(ConduitData, 1);
 
         retval = gnome_pilot_conduit_standard_new("ExpenseDB", Expense_Creator, NULL);
         g_assert(retval != NULL);
 
-        gtk_signal_connect(retval, "copy_from_pilot", (GtkSignalFunc)copy_from_pilot ,NULL);
+        g_signal_connect(retval, "copy_from_pilot", (GCallback)copy_from_pilot ,NULL);
         /*
-          gtk_signal_connect(retval, "copy_to_pilot", (GtkSignalFunc) ,NULL);
-          gtk_signal_connect(retval, "merge_to_pilot", (GtkSignalFunc) ,NULL);
-          gtk_signal_connect(retval, "merge_from_pilot", (GtkSignalFunc) ,NULL);
+          g_signal_connect(retval, "copy_to_pilot", (GCallback) ,NULL);
+          g_signal_connect(retval, "merge_to_pilot", (GCallback) ,NULL);
+          g_signal_connect(retval, "merge_from_pilot", (GCallback) ,NULL);
         */
-        gtk_signal_connect(retval, "synchronize", (GtkSignalFunc)synchronize ,NULL);
-	gtk_signal_connect (retval, "create_settings_window", (GtkSignalFunc) create_settings_window, NULL);
-	gtk_signal_connect (retval, "display_settings", (GtkSignalFunc) display_settings, NULL);
-	gtk_signal_connect (retval, "save_settings", (GtkSignalFunc) save_settings, NULL);
-	gtk_signal_connect (retval, "revert_settings", (GtkSignalFunc) revert_settings, NULL);
+        g_signal_connect(retval, "synchronize", (GCallback)synchronize ,NULL);
+	g_signal_connect (retval, "create_settings_window", (GCallback) create_settings_window, NULL);
+	g_signal_connect (retval, "display_settings", (GCallback) display_settings, NULL);
+	g_signal_connect (retval, "save_settings", (GCallback) save_settings, NULL);
+	g_signal_connect (retval, "revert_settings", (GCallback) revert_settings, NULL);
 
 	load_configuration(&cfg,pilotId);
 	cfg2 = dupe_configuration(cfg);
-	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONFIG,cfg);
-	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_OLDCONFIG,cfg2);
-        gtk_object_set_data(retval,OBJ_DATA_CONDUIT,(gpointer)cd);
+	g_object_set_data(G_OBJECT(retval),OBJ_DATA_CONFIG,cfg);
+	g_object_set_data(G_OBJECT(retval),OBJ_DATA_OLDCONFIG,cfg2);
+        g_object_set_data(G_OBJECT(retval),OBJ_DATA_CONDUIT,(gpointer)cd);
         
         return GNOME_PILOT_CONDUIT(retval); 
 }
@@ -658,6 +728,119 @@ void conduit_destroy_gpilot_conduit( GnomePilotConduit *c )
         cd = GET_CONDUIT_DATA(c);
 
         destroy_configuration( &cc );
-        gtk_object_destroy(GTK_OBJECT(c));
+	g_object_unref (G_OBJECT (c));
 }
 
+#define OLD_PREFIX ".gnome2/gnome-pilot.d"
+#define NEW_PREFIX ".gnome-pilot"
+
+#define IS_STR_SET(x) (x != NULL && x[0] != '\0')
+
+static void
+migrate_conf (const gchar *old, const gchar *new)
+{
+	gchar *basename = g_path_get_dirname (new);
+
+	if (!g_file_test (basename, G_FILE_TEST_EXISTS)) {
+		g_mkdir_with_parents (basename, S_IRUSR | S_IWUSR | S_IXUSR);
+	} else {
+		if (!g_file_test (basename, G_FILE_TEST_IS_DIR)) {
+			gchar *tmp = g_strdup_printf ("%s.old", basename);
+			rename (basename, tmp);
+			g_free (tmp);
+			g_mkdir_with_parents (basename, S_IRUSR | S_IWUSR | S_IXUSR);
+		}
+	}
+	g_free (basename);
+
+	if (g_file_test (new, G_FILE_TEST_IS_REGULAR)) {
+		return;
+	} else if (g_file_test (old, G_FILE_TEST_IS_REGULAR)) {
+		rename (old, new);
+	} else {
+		creat (new, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+	}
+}
+
+static GKeyFile*
+get_kfile (const gchar *conf)
+{
+	GKeyFile   *kfile = g_key_file_new ();
+	const char *homedir = g_getenv ("HOME");
+	char       *old = NULL;
+	char       *new = NULL;
+
+	if (!homedir)
+		homedir = g_get_home_dir ();
+
+	old = g_build_filename (homedir, OLD_PREFIX, conf, NULL);
+	new = g_build_filename (homedir, NEW_PREFIX, conf, NULL);
+
+	migrate_conf (old, new);
+
+	g_key_file_load_from_file (kfile, new, G_KEY_FILE_NONE, NULL);
+	g_key_file_set_list_separator (kfile, ' ');
+
+	g_free (new);
+	g_free (old);
+	return kfile;
+}
+
+static gboolean
+save_config (GKeyFile    *kfile,
+	     const gchar *conf)
+{
+	const char *homedir = g_getenv ("HOME");
+        GError     *error = NULL;
+        gchar      *data = NULL;
+        gsize       size;
+	gchar 	   *filename = NULL;
+
+	g_return_val_if_fail (kfile, FALSE);
+	g_return_val_if_fail (IS_STR_SET (conf), FALSE);
+
+	if (!homedir)
+		homedir = g_get_home_dir ();
+
+	filename = g_build_filename (homedir, NEW_PREFIX, conf, NULL);
+
+	if (! g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
+		g_free (filename);
+		g_warning ("File %s does not exsit", filename);
+		return FALSE;
+	}
+
+        g_message ("Saving config to disk...");
+
+	g_key_file_set_list_separator (kfile, ' ');
+ 	data = g_key_file_to_data (kfile, &size, &error);
+        if (error) {
+                g_warning ("Could not get config data to write to file, %s",
+                           error->message);
+                g_error_free (error);
+
+                return FALSE;
+        }
+
+        g_file_set_contents (filename, data, size, &error);
+        g_free (data);
+
+        if (error) {
+                g_warning ("Could not write %" G_GSIZE_FORMAT " bytes to file '%s', %s",
+                           size,
+                           filename,
+                           error->message);
+                g_free (filename);
+                g_error_free (error);
+
+                return FALSE;
+        }
+
+        g_message ("Wrote config to '%s' (%" G_GSIZE_FORMAT " bytes)",
+                   filename,
+                   size);
+
+	g_free (filename);
+
+	return TRUE;
+}
