@@ -44,8 +44,8 @@
 #include <errno.h>
 #include <ctype.h>
 #include <dirent.h>
-#include <gpilotd/gnome-pilot-conduit.h>
-#include <gpilotd/gnome-pilot-conduit-standard-abs.h>
+#include <gnome-pilot-conduit.h>
+#include <gnome-pilot-conduit-standard-abs.h>
 
 #include "memo_file_conduit.h"
 
@@ -1262,13 +1262,13 @@ insert_ignore_space (GtkEditable    *editable, const gchar    *text,
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
 		if (isspace (text[0])) {
-			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 			return;
 		}
 	} else { 
 		for (i=0; i<len; i++) {
 			if (isspace (text[i])) {
-				g_signal_stop_emission_by_name (GTK_OBJECT (editable),"insert_text");
+				g_signal_stop_emission_by_name (G_OBJECT (editable),"insert_text");
 				return;
 			}
 		}
@@ -1284,7 +1284,7 @@ insert_numeric_callback (GtkEditable    *editable, const gchar    *text,
 
 	for (i=0; i<len; i++) {
 		if (!isdigit (text[i])) {
-			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 			return;
 		}
 	}
@@ -1307,7 +1307,7 @@ secret_toggled_cb (GtkWidget *widget, gpointer data)
 	GnomePilotConduit *conduit = (GnomePilotConduit*)data;
 	ConduitCfg * curState = GET_CONDUIT_CFG (conduit);
 	GtkWidget * main_widget = GET_CONDUIT_WINDOW (conduit);
-	curState->open_secret = GTK_TOGGLE_BUTTON (widget)->active;
+	curState->open_secret = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 	gtk_widget_set_sensitive (g_object_get_data (G_OBJECT (main_widget),"secret_mode"), curState->open_secret);
 	gtk_widget_set_sensitive (g_object_get_data (G_OBJECT (main_widget),"secret_label"), curState->open_secret);
 }
@@ -1342,7 +1342,7 @@ static GtkWidget
 		gtk_entry_set_max_length (GTK_ENTRY(entry), 128);
 		g_object_set_data (G_OBJECT (vbox), fields[i].obj_data, entry);
 		gtk_table_attach (GTK_TABLE (table), entry, 2, 3, i, i+1, 0, 0, 0, 0);
-		g_signal_connect (GTK_OBJECT (entry), "insert_text",
+		g_signal_connect (G_OBJECT (entry), "insert_text",
 				   G_CALLBACK (fields[i].insert_func),
 				   NULL);
 	}
@@ -1350,7 +1350,7 @@ static GtkWidget
 	button = gtk_check_button_new ();
 
 	g_object_set_data (G_OBJECT (vbox),"secret_on", button);
-	g_signal_connect (GTK_OBJECT (button), "toggled",
+	g_signal_connect (G_OBJECT (button), "toggled",
 			   G_CALLBACK (secret_toggled_cb),
 			   conduit);
 	gtk_table_attach (GTK_TABLE (table), button, 0, 1, 5, 6, 0, 0, 0, 0); /* 5, 6 is badly hard-coded here. */
@@ -1468,7 +1468,7 @@ revert_settings  (GnomePilotConduit *conduit, gpointer data)
 GnomePilotConduit *
 conduit_get_gpilot_conduit (guint32 pilotId)
 {
-	GtkObject *retval;
+	GObject *retval;
 
 	ConduitData *cd = g_new0 (ConduitData, 1);
 	ConduitCfg *cfg, *cfg2;
@@ -1541,6 +1541,8 @@ conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 	if (cfg2) {
 		destroy_configuration (&cfg2);
 	}
+
+	g_object_unref (G_OBJECT (conduit));
 }
 
 
