@@ -30,7 +30,7 @@
 #include <pi-dlp.h>
 #include <pi-version.h>
 
-#include <gpilotd/gnome-pilot-conduit-standard.h>
+#include <gnome-pilot-conduit-standard.h>
 
 #include "time-conduit.h"
 
@@ -189,7 +189,7 @@ synchronize (GnomePilotConduit *c,
 GnomePilotConduit *
 conduit_load_gpilot_conduit (GPilotPilot *pilot)
 {
-	GtkObject *retval;
+	GObject *retval;
 	ConduitCfg *cfg, *cfg2;
 	
 	retval = gnome_pilot_conduit_standard_new ("Unsaved Preferences", (guint32)0x70737973, pilot);
@@ -221,7 +221,7 @@ conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 	
 	destroy_configuration(&cfg);
 	if(cfg2) destroy_configuration(&cfg2);
-	gtk_object_destroy (GTK_OBJECT (conduit));
+	g_object_unref (G_OBJECT (conduit));
 }
 
 
